@@ -1,3 +1,4 @@
+from typing import Tuple, Optional
 import os
 import sys
 import argparse
@@ -5,7 +6,8 @@ import asyncio
 
 import urwid
 
-from ovshell.app import OpenvarioShellImpl, ScreenManagerImpl
+from ovshell.app import OpenvarioShellImpl
+from ovshell.screen import ScreenManagerImpl
 from ovshell.ui.mainmenu import MainMenuActivity
 
 parser = argparse.ArgumentParser(description="Shell for Openvario")
@@ -22,6 +24,12 @@ parser.add_argument(
     required=False,
     help="Run in simulated mode (on provided root filesystem).",
 )
+parser.add_argument(
+    "--run",
+    metavar="APP",
+    required=False,
+    help="Run given app automatically on startup. Useful during app development",
+)
 
 
 def debounce_esc(keys, raw):
@@ -49,8 +57,9 @@ def debounce_esc(keys, raw):
     return filtered
 
 
-def startui(app: OpenvarioShellImpl) -> None:
-    app.screen.push_activity(MainMenuActivity(app))
+def startui(ctx: Tuple[OpenvarioShellImpl, Optional[str]]) -> None:
+    shell, autostart = ctx
+    shell.screen.push_activity(MainMenuActivity(shell, autostart))
 
 
 def run(argv) -> None:
@@ -63,6 +72,7 @@ def run(argv) -> None:
         ("li normal", "light cyan", "black", ""),
         ("li focus", "white", "dark red", ""),
         ("pg normal", "white", "black", "standout"),
+        ("pg inverted", "black", "light gray", "standout"),
         ("pg complete", "white", "dark magenta"),
         ("pg smooth", "dark magenta", "black"),
         ("screen header", "white", "brown", "standout"),
@@ -71,7 +81,7 @@ def run(argv) -> None:
         ("success message", "light green", "black", ""),
         ("success banner", "white", "dark green", ""),
         ("error message", "light red", "black", ""),
-        ("error banner", "white", "dark red", ""),
+        ("error banner", "yellow", "dark red", ""),
         ("progress", "light magenta", "black", ""),
         ("remark", "dark gray", "black", ""),
         ("topbar", "black", "white", ""),
@@ -80,9 +90,6 @@ def run(argv) -> None:
         ("li normal light", "dark blue", "white", ""),
     ]
 
-    # btxt = urwid.BigText("Openvario", urwid.font.Thin6x6Font())
-    # splash = urwid.Filler(urwid.Padding(btxt, "center", "clip"), "middle")
-
     asyncioloop = asyncio.get_event_loop()
     evl = urwid.AsyncioEventLoop(loop=asyncioloop)
 
@@ -95,7 +102,8 @@ def run(argv) -> None:
     shell = OpenvarioShellImpl(screen, config=args.config, rootfs=args.sim)
     shell.extensions.load_all(shell)
     shell.apps.install_new_apps()
-    asyncioloop.call_soon(startui, shell)
+
+    asyncioloop.call_soon(startui, (shell, args.run))
 
     try:
         urwidloop.run()
