@@ -9,13 +9,16 @@ from typing import (
     Tuple,
     TypeVar,
     Type,
+    Coroutine,
 )
 from typing_extensions import Protocol
 from abc import abstractmethod
 from dataclasses import dataclass
+import asyncio
 
 import urwid
 
+UrwidText = Union[str, Tuple[str, str], List[Tuple[str, str]]]
 BasicType = Union[int, str, float]
 JsonType = Union[BasicType, List[BasicType], Dict[str, BasicType]]
 
@@ -82,10 +85,16 @@ class Activity(Protocol):
     def create(self) -> urwid.Widget:
         pass
 
+    def activate(self) -> None:
+        pass
+
     def destroy(self) -> None:
         pass
 
-    def activate(self) -> None:
+    def hide(self) -> None:
+        pass
+
+    def show(self) -> None:
         pass
 
 
@@ -118,6 +127,10 @@ class ScreenManager(Protocol):
     def push_modal(self, activity: Activity, options: ModalOptions) -> None:
         pass
 
+    @abstractmethod
+    def spawn_task(self, activity: Activity, coro: Coroutine) -> asyncio.Task:
+        pass
+
 
 class OpenVarioOS(Protocol):
     @abstractmethod
@@ -170,12 +183,19 @@ class AppInfo:
 
 
 class AppManager(Protocol):
+    @abstractmethod
     def list(self) -> Iterable[AppInfo]:
         pass
 
+    @abstractmethod
+    def get(self, appid: str) -> Optional[AppInfo]:
+        pass
+
+    @abstractmethod
     def pin(self, app: AppInfo, persist: bool = False) -> None:
         pass
 
+    @abstractmethod
     def unpin(self, app: AppInfo, persist: bool = False) -> None:
         pass
 
