@@ -103,7 +103,7 @@ class SettingRowItem(urwid.WidgetWrap):
         self._value_w = urwid.Text(setting.value_label)
         self._value_popup_w = SettingsPopUpLauncher(setting, self._value_w)
         cols = urwid.Columns(
-            [("weight", 1, self._title_w), ("weight", 2, self._value_popup_w)]
+            [("weight", 1, self._title_w), ("weight", 1, self._value_popup_w)]
         )
         wdg = urwid.AttrMap(cols, "li normal", "li focus")
         super().__init__(wdg)
@@ -150,7 +150,7 @@ class SettingsPopUpLauncher(urwid.PopUpLauncher):
         }
 
 
-class SettingsActivity:
+class SettingsActivity(protocol.Activity):
     def __init__(self, shell: protocol.OpenVarioShell) -> None:
         self.shell = shell
 
@@ -174,9 +174,3 @@ class SettingsActivity:
             settings.extend(ext.list_settings())
 
         return sorted(settings, key=lambda s: -s.priority)
-
-    def activate(self) -> None:
-        pass
-
-    def destroy(self) -> None:
-        pass
